#
# spec file for package dtkwidget
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2018 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libver 2

Name:           dtkwidget
Version:        2.0.9.11
Release:        lp151.1.1
Summary:        Deepin graphical user interface library
License:        GPL-3.0-or-later
Group:          System/GUI/Other
Url:            https://github.com/linuxdeepin/dtkwidget
Source0:        https://github.com/linuxdeepin/dtkwidget/archive/%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTEAM dtkwidget-fix-lost-pkgconfig.patch hillwood@opensuse.org - fix lost pkgconfig
Patch0:         dtkwidget-fix-lost-pkgconfig.patch
BuildRequires:  fdupes
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-private-headers-devel
BuildRequires:  libqt5-qtdeclarative-devel
BuildRequires:  libqt5-qtmultimedia-devel
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(dframeworkdbus)
BuildRequires:  pkgconfig(dtkcore)
BuildRequires:  pkgconfig(gsettings-qt)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xi)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Deepint Tool Kit (Dtk) is the base devlopment tool of all C++/Qt Developer 
work on Deepin.

%package -n lib%{name}%{libver}
Summary:        Libraries for dtkwidget
Group:          System/Libraries

%description -n lib%{name}%{libver}
The dtkwidget-devel package contains the header files and developer
docs for dtkcore.

%package devel
Summary:        Development tools for dtkwidget
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{libver} = %{version}

%description devel
The dtkwidget-devel package contains the header files and developer
docs for dtkcore.

%prep
%setup -q
%patch0 -p1

%build
# sed -i "s/lrelease/lrelease-qt5/g" tools/translate_generation.*
%qmake5 DEFINES+=QT_NO_DEBUG_OUTPUT \
        PREFIX=%{_prefix} \
        LIB_INSTALL_DIR=%{_libdir}
make %{?_smp_mflags}

%install
%qmake5_install

# Remove useless files
rm -rf %{buildroot}/usr/tests
mkdir -p %{buildroot}%{_libdir}/qt5
mv %{buildroot}/mkspecs %{buildroot}%{_libdir}/qt5/

%fdupes %{buildroot}

%post -n lib%{name}%{libver} -p /sbin/ldconfig

%postun -n lib%{name}%{libver} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc LICENSE README.md
%dir %{_datadir}/dtkwidget
%{_datadir}/dtkwidget/translations
%dir %{_libexecdir}/dtk2
%{_libexecdir}/dtk2/dtk-svgc

%files -n lib%{name}%{libver}
%defattr(-,root,root,-)
%{_libdir}/lib%{name}.so.*

%files devel
%defattr(-,root,root,-)
%dir %{_includedir}/libdtk-*
%{_includedir}/libdtk-*/DWidget
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/lib%{name}.so
%dir %{_libdir}/cmake
%{_libdir}/cmake/*
%dir %{_libdir}/qt5
%dir %{_libdir}/qt5/mkspecs
%{_libdir}/qt5/mkspecs/modules

%changelog
* Thu Dec 20 2018 hillwood@opensuse.org
- Update version to 2.0.9.11
  * allowed set a expected icon size for DDialog
  * DWindowManagerHelper: return all windowId and current workspace windowId
  * Fix the dialog type window will be closed after pressing Super+D
  * Fix workaround QTapAndHoldGesture comes late than right press in dde-daemon
  * DPasswdEditAnimated: modify parent for tip widget
  * dtabbar: horizontal dragging delays.
  * set QTapAndHoldGesture::timeout in DApplication
  * DWindowManagerHelper: add inteface: "windowManagerName"
  * DPasswdEditAnimated: add updateAlertPosition() func.
  * DTickEffect: change scroll speed
  * Fix passwdeditanimated: hide alert flash.
* Fri Nov  9 2018 hillwood@opensuse.org
- Update version to 2.0.9.8
  * Fixd bugs
  * Updated features
* Tue Mar 27 2018 hillwood@opensuse.org
- Update version to 2.0.7.2
  * Add DAbstractDialog::move(int, int) and
    DAbstractDialog::setGeometry(int, int, int, int)
  * Move the DAbstractDialog window is invalid
  * Can not auto adjust dialog position
  * Wait dbus call return
* Mon Mar 19 2018 hillwood@opensuse.org
- Update version to 2.0.7.1
  * control single instance by env
  * support hide group
  * add DFileDialog
  * dynamic website info in about dialog
  * create cmake file by dtk_cmake
  * support qt module
  * update password edit style
  * auto scroll when move/drag tab
  * support new and legacy dman interface
  * support set combobox data with QMap
  * fixed the QPrintDialog theme to dlight
  * support dynamic property
  * fixed the width of the DTabBar add button to 48
  * add buildDtkVersion/runtimeDtkVersion to DApplication
  * parser correctly when version has '.is.'
  * follow parent/toplevelWidget flags
  * support configurable whether to redefine the window content when dxcb is
    turned on
  * add "target" argument for DTabBar::tabDroped
  * auto hide title when fullscreen
  * add propertys maskColor and flashColor of DTabBar
  * support drag tab to other for DTabBar
  * add DToast
  * add window title
  * not set AA_DontCreateNativeWidgetSiblings if dxcb version greater then 1.1.5
  * set version form changelog
  * add property "realWindowId" for DPlatformWindowHandle
  * add the property of the menu
  * add initialize text parameter.
  * Fix reset short cut not show
  * please read CHANGELOG.md to get more changes
- Add dtkwidget-fix-lost-pkgconfig.patch, fix lost pkgconfig settings.
* Mon Mar 19 2018 hillwood@opensuse.org
- Split cmake-dtkwidget.
* Thu Mar  1 2018 hillwood@opensuse.org
- Update version to 2.0.6.1
  * Fix bugs
  * support new dman interface
  * add DSuggestButton and DStyleOption
  * not fixed font size of DDialog
  * DTabBar add scroll buttons
  * add the "dtkwidget_global.h" header file
  * add the "DtkWidgets" header file
  * add animation for DTabBar on drag move tabs
  * support dual-click to make crumb
  * add the DTabBar widget
* Thu Nov 30 2017 hillwood@opensuse.org
- Update to 2.0.5.2
  * add bordless window on mac
  * support DTK_TITLE_DRAG_WINDOW on mac
  * use D_DECL_DEPRECATED
  * add DFileChooserEdit light theme
  * show system menu on right mouse button press of DTitlebar
  * Fix window motif hints is error of DMainWindow
  * fix macos build failed
  * Fix popup system menu in window content
  * Fix correct typos in multiple files
  * Fix windows build failed
  * Fix add DTK_DMAN_PORTAL support
  * change the QGuiApplication::platformName() to "xcb" on dxcb platform
  * isDXcbPlatform for new version dxcb plugin ([d8b5c040](d8b5c040))
  * DRegionMonitor: properly handle scale ([95766b45](95766b45))
  * DRegionMonitor: possible double freed object ([708a5fbe](708a5fbe))
  * add shortcut to DMainWindow ([5e9d5b6c](5e9d5b6c))
  * add F1 shortcut ([7e311564](7e311564))
  * add setState to DImageButton ([fcf9c3ef](fcf9c3ef))
  * optimize shift up/down keypress for DSimpleListView ([7019967f](7019967f))
  * DTitlebar add disable API ([ea92fae9](ea92fae9))
  * add embed mode ([266f4337](266f4337))
  * add trash dbus interface ([b88efbb8](b88efbb8))
  * change productIcon to QIcon ([2a914b51](2a914b51))
  * Add DHiDPIHelper class ([0fdbcf60](0fdbcf60))
  * daboutdialog deepin logo support hidpi ([405352f0](405352f0))
  * Set AA_UseHighDpiPixmaps on DApplication ([e9fb9fcf](e9fb9fcf))
  * add svgc ([fedb3860](fedb3860))
  * lineedit support hidpi ([026ecb65](026ecb65))
  * titlebar buttons support hidpi ([56b11074](56b11074))
  * titlebar support hidpi ([dd537c17](dd537c17))
  * add dbus singleton ([6ae2978f](6ae2978f))
  * dpicturesequenceview support @2x files ([a299ef09](a299ef09))
  * dvideowidget support set device ratio ([74eaa1d6](74eaa1d6))
  * add DWaterProgress::setTextVisible ([a61d2e88](a61d2e88))
  * add DSettingsWidgetFactory ([f14ff92f](f14ff92f))
  * add radius set interface to pageindicator ([7bc360c0](7bc360c0))
  * add border and shadow to DWaterProgress ([ecc4ba17](ecc4ba17))
  * DWaterProgress support hidpi ([94350b7f](94350b7f))
  * DArrowRectangle support hidpi ([d7d6a876](d7d6a876))
  * Fix windows build failed ([1b40d6a7](1b40d6a7))
  * Fix disable _q_onTopWindowMotifHintsChanged when use DTitlebar::setWindowFlags
  * Fix draw pixmap size error on DTitlebar ([228fd523](228fd523))
  * Fix DTitlebar button is hidden on the non DMainWindow windows
  ([7b131a72](7b131a72))
  * Fix paint DBlurEffectWindow error if device pixel ratio is not 1
    ([dff92b1b](dff92b1b))
  * Fix min/maximize button is hidden on DMainWindow ([89279ac4](89279ac4))
  * fix hidpi load icon size ([79e81f94](79e81f94))
  * update DDialog message style ([2c6133c1](2c6133c1))
  * Fix crash on multiple apps registered xmouseare ([dea8651f](dea8651f))
  * Fix icon of DSearchEdit not clear on hidpi ([6ebada94](6ebada94))
  * DSimpleListview arrow isn't visible ([b08e7f1c](b08e7f1c))
  * DAboutDialog icon not supporting hidpi ([6ec60734](6ec60734))
  * fix dtk-svgc crash if no font init ([83857265](83857265))
  * fix settings dialog style ([797c3e35](797c3e35))
  * dialog use same style as light ([9d7d4a61](9d7d4a61))
  * fix windows build failed ([7f31ea48](7f31ea48))
  * fix dialog size error on hidpi ([b9273c72](b9273c72))
  * update translation ([0045c39e](0045c39e))
  * crash if setIcon with svg ([9b577be3](9b577be3))
  * remove useless image ([10c9607c](10c9607c))
  * remove private header file ([61b375b2](61b375b2))
  * dswitchbutton error calculation radius ([d742b169](d742b169))
  * dimagebutton private not initialized ([146d893e](146d893e))
  * DArrowRectangle: arrow position error ([592187fb](592187fb))
  * DPasswordEdit: password edit icon out of content ([c1fe173a](c1fe173a))
* Fri Nov  3 2017 dimstar@opensuse.org
- Set Group for shared library package to 'System/Libraries'.
* Thu Nov  2 2017 hillwood@opensuse.org
- Update to 2.0.2
  * Use librsvg-2.0
  * Use dframeworkdbus
  * Use QML
* Tue Oct  3 2017 hillwood@opensuse.org
- Change Group tag.
* Wed Sep 27 2017 hillwood@opensuse.org
- Initial package.
